# -*- coding: utf-8 -*-
# @Created : maker
# @Time    : 1992
# @Project : chpypi
# @Software: PyCharm
from chpypi import getproxies
from chpypi import login


class HTTPTOOLS:
    def __init__(self):
        ...

    @classmethod
    def login_chen_hai(cls):
        return login.LOGIN

    @classmethod
    def get_proxies(cls):
        return getproxies.PROXIES






